pub struct Create<'a, AI> {
pub funder: &'a AI,
pub account: &'a AI,
pub lamports: u64,
pub space: u64,
pub owner: &'a Pubkey,
}Expand description
Argument for SystemProgram::create_account
Fields
funder: &'a AIThe funder of the new account
account: &'a AIThe account to create
lamports: u64The amount of lamports to give the new account
space: u64The amount of space to allocate to the new account
owner: &'a PubkeyThe owning program of the new account